==> activity-center-biz-1.2.3.9-zlh-20160909.113819-2-sources.jar: cn/com/duiba/activity/center/biz/service/impl/ActivityCategoryServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.impl
 * Date:2016年6月7日上午9:05:19
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.biz.dao.category.ActivityCategoryDao;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryService;

/**
 * ClassName:ActivityCategoryServiceImpl <br/>
 * Date:     2016年6月7日 上午9:05:19 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service("activityCategoryService")
public class ActivityCategoryServiceImpl implements ActivityCategoryService{
    @Autowired
    private ActivityCategoryDao activityCategoryDao;
    @Override
    public Long createCategory(String name, String content) {
        ActivityCategoryEntity e=new ActivityCategoryEntity();
        e.setName(name);
        e.setContent(content);
        activityCategoryDao.insert(e);
        return e.getId();
    }

    @Override
    public Boolean editCategoryContent(long id, String name, String content) {
        int ret=activityCategoryDao.updateCategoryContent(id, name, content);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public Boolean enableCategory(long id) {
        int ret=activityCategoryDao.updateCategoryEnable(id);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public Boolean disableCategory(long id) {
        int ret=activityCategoryDao.updateCategoryDisable(id);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public List<ActivityCategoryEntity> findAll() {
        return activityCategoryDao.selectAll();
    }
    
    @Override
    public ActivityCategoryEntity findDefaultCategory() {
        List<ActivityCategoryEntity> list=findAll();
        for(ActivityCategoryEntity e:list){
            if(e.getDefaultCategory()==true){
                return e;
            }
        }
        return null;
    }

	@Override
	public ActivityCategoryEntity findById(long id) {
		return activityCategoryDao.select(id);
	}

}

==> activity-center-biz-1.2.9.8.zlh-20161114.112404-1-sources.jar: cn/com/duiba/activity/center/biz/service/impl/ActivityCategoryServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.impl
 * Date:2016年6月7日上午9:05:19
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.biz.dao.category.ActivityCategoryDao;
import cn.com.duiba.activity.center.biz.dao.category.ActivityCategorySpecifyDao;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;
import cn.com.duiba.activity.center.biz.entity.chaos.ActivityCategorySpecifyEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryService;

/**
 * ClassName:ActivityCategoryServiceImpl <br/>
 * Date:     2016年6月7日 上午9:05:19 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service("activityCategoryService")
public class ActivityCategoryServiceImpl implements ActivityCategoryService{
    @Autowired
    private ActivityCategoryDao activityCategoryDao;
    @Autowired
    private ActivityCategorySpecifyDao activityCategorySpecifyDao;
    
    @Override
    public Long createCategory(String name, String content) {
        ActivityCategoryEntity e=new ActivityCategoryEntity();
        e.setName(name);
        e.setContent(content);
        activityCategoryDao.insert(e);
        return e.getId();
    }

    @Override
    public Boolean editCategoryContent(long id, String name, String content) {
        int ret=activityCategoryDao.updateCategoryContent(id, name, content);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public Boolean enableCategory(long id) {
        int ret=activityCategoryDao.updateCategoryEnable(id);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public Boolean disableCategory(long id) {
        int ret=activityCategoryDao.updateCategoryDisable(id);
        if(ret==1){
            return true;
        }
        return false;
    }

    @Override
    public List<ActivityCategoryEntity> findAll() {
        return activityCategoryDao.selectAll();
    }
    
    @Override
    public List<ActivityCategoryEntity> findByIds(List<Long> ids) {
        return activityCategoryDao.findByIds(ids);
    }
    
    @Override
    public ActivityCategoryEntity findDefaultCategory() {
        List<ActivityCategoryEntity> list=findAll();
        for(ActivityCategoryEntity e:list){
            if(e.getDefaultCategory()==true){
                return e;
            }
        }
        return null;
    }

	@Override
	public ActivityCategoryEntity findById(long id) {
		return activityCategoryDao.select(id);
	}

    @Override
    public Boolean deleteCategory(long id) {
        int ret = activityCategoryDao.deleteById(id);
        return ret > 0;
    }

    @Override
    public List<ActivityCategoryEntity> findCategoryByAppId(Long appId) {
        List<ActivityCategoryEntity> enableCategoryList = activityCategoryDao.selectEnableCategory();
        //查询已定向给app的子页面
        List<ActivityCategorySpecifyEntity> specifyList = activityCategorySpecifyDao.selectByAppSpecifys(appId);
        List<Long> appSpecifyIdList = new ArrayList<Long>();
        for(ActivityCategorySpecifyEntity entity : specifyList){
            appSpecifyIdList.add(entity.getActivityCategoryId());
        }
        Iterator<ActivityCategoryEntity> it = enableCategoryList.iterator();
        //没有定向给app的子页面过滤掉
        while(it.hasNext()){
            ActivityCategoryEntity activityCategoryEntity = it.next();
            if(activityCategoryEntity.getSpecify() && !appSpecifyIdList.contains(activityCategoryEntity.getId())){
                it.remove();
            }
        }
        return enableCategoryList;
    }
	
}
